You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@guacamole.apache.org by mj...@apache.org on 2018/01/03 18:33:42 UTC

[1/6] guacamole-client git commit: GUACAMOLE-237: Move to new getUserMedia method.

Repository: guacamole-client
Updated Branches:
  refs/heads/master d73a0ece2 -> c170612cd


GUACAMOLE-237: Move to new getUserMedia method.


Project: http://git-wip-us.apache.org/repos/asf/guacamole-client/repo
Commit: http://git-wip-us.apache.org/repos/asf/guacamole-client/commit/1c27c66c
Tree: http://git-wip-us.apache.org/repos/asf/guacamole-client/tree/1c27c66c
Diff: http://git-wip-us.apache.org/repos/asf/guacamole-client/diff/1c27c66c

Branch: refs/heads/master
Commit: 1c27c66cb345536574348aa7a1102cbc0859243d
Parents: d73a0ec
Author: Nick Couchman <vn...@apache.org>
Authored: Mon Jan 1 22:11:45 2018 -0500
Committer: Nick Couchman <vn...@apache.org>
Committed: Mon Jan 1 22:11:45 2018 -0500

----------------------------------------------------------------------
 guacamole-common-js/src/main/webapp/modules/AudioRecorder.js | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/guacamole-client/blob/1c27c66c/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
----------------------------------------------------------------------
diff --git a/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js b/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
index 3a73d1d..454f3f6 100644
--- a/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
+++ b/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
@@ -188,10 +188,10 @@ Guacamole.RawAudioRecorder = function RawAudioRecorder(stream, mimetype) {
      * @type Function
      */
 
-    if (navigator.mediaDevices === undefined)
+    if (!navigator.mediaDevices)
         navigator.mediaDevices = {};
 
-    if (navigator.mediaDevices.getUserMedia === undefined)
+    if (!navigator.mediaDevices.getUserMedia)
         navigator.mediaDevices.getUserMedia = (navigator.getUserMedia
                 || navigator.webkitGetUserMedia
                 || navigator.mozGetUserMedia


[2/6] guacamole-client git commit: GUACAMOLE-237: Define navigator.mediaDevices and getUserMedia when undefined.

Posted by mj...@apache.org.
GUACAMOLE-237: Define navigator.mediaDevices and getUserMedia when undefined.


Project: http://git-wip-us.apache.org/repos/asf/guacamole-client/repo
Commit: http://git-wip-us.apache.org/repos/asf/guacamole-client/commit/f6291c03
Tree: http://git-wip-us.apache.org/repos/asf/guacamole-client/tree/f6291c03
Diff: http://git-wip-us.apache.org/repos/asf/guacamole-client/diff/f6291c03

Branch: refs/heads/master
Commit: f6291c034cd3e8d672ee98afef1d7c86bba555cd
Parents: 1c27c66
Author: Nick Couchman <vn...@apache.org>
Authored: Tue Jan 2 11:43:24 2018 -0500
Committer: Nick Couchman <vn...@apache.org>
Committed: Tue Jan 2 11:43:24 2018 -0500

----------------------------------------------------------------------
 .../src/main/webapp/modules/AudioRecorder.js        | 16 ++++++++++------
 1 file changed, 10 insertions(+), 6 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/guacamole-client/blob/f6291c03/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
----------------------------------------------------------------------
diff --git a/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js b/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
index f925716..3a73d1d 100644
--- a/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
+++ b/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
@@ -187,11 +187,15 @@ Guacamole.RawAudioRecorder = function RawAudioRecorder(stream, mimetype) {
      *
      * @type Function
      */
-    var getUserMedia = (navigator.mediaDevices.getUserMedia
-            || navigator.getUserMedia
-            || navigator.webkitGetUserMedia
-            || navigator.mozGetUserMedia
-            || navigator.msGetUserMedia).bind(navigator);
+
+    if (navigator.mediaDevices === undefined)
+        navigator.mediaDevices = {};
+
+    if (navigator.mediaDevices.getUserMedia === undefined)
+        navigator.mediaDevices.getUserMedia = (navigator.getUserMedia
+                || navigator.webkitGetUserMedia
+                || navigator.mozGetUserMedia
+                || navigator.msGetUserMedia).bind(navigator);
 
     /**
      * Guacamole.ArrayBufferWriter wrapped around the audio output stream
@@ -420,7 +424,7 @@ Guacamole.RawAudioRecorder = function RawAudioRecorder(stream, mimetype) {
     var beginAudioCapture = function beginAudioCapture() {
 
         // Attempt to retrieve an audio input stream from the browser
-        getUserMedia({ 'audio' : true }, function streamReceived(stream) {
+        navigator.mediaDevices.getUserMedia({ 'audio' : true }, function streamReceived(stream) {
 
             // Create processing node which receives appropriately-sized audio buffers
             processor = context.createScriptProcessor(BUFFER_SIZE, format.channels, format.channels);


[5/6] guacamole-client git commit: GUACAMOLE-237: Make standard comments instead of JSDoc comments.

Posted by mj...@apache.org.
GUACAMOLE-237: Make standard comments instead of JSDoc comments.


Project: http://git-wip-us.apache.org/repos/asf/guacamole-client/repo
Commit: http://git-wip-us.apache.org/repos/asf/guacamole-client/commit/e1443d87
Tree: http://git-wip-us.apache.org/repos/asf/guacamole-client/tree/e1443d87
Diff: http://git-wip-us.apache.org/repos/asf/guacamole-client/diff/e1443d87

Branch: refs/heads/master
Commit: e1443d87b9955927394aa73323b4fe039ebf46f2
Parents: f0a658b
Author: Nick Couchman <vn...@apache.org>
Authored: Wed Jan 3 13:07:24 2018 -0500
Committer: Nick Couchman <vn...@apache.org>
Committed: Wed Jan 3 13:07:24 2018 -0500

----------------------------------------------------------------------
 .../src/main/webapp/modules/AudioRecorder.js        | 16 ++++++----------
 1 file changed, 6 insertions(+), 10 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/guacamole-client/blob/e1443d87/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
----------------------------------------------------------------------
diff --git a/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js b/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
index c1bb4eb..d91bf50 100644
--- a/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
+++ b/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
@@ -181,19 +181,15 @@ Guacamole.RawAudioRecorder = function RawAudioRecorder(stream, mimetype) {
      */
     var context = Guacamole.AudioContextFactory.getAudioContext();
 
-    /**
-     * Some browsers do not implement navigator.mediaDevices - this
-     * shims in this functionality to ensure code compatibility.
-     */
+    // Some browsers do not implement navigator.mediaDevices - this
+    // shims in this functionality to ensure code compatibility.
     if (!navigator.mediaDevices)
         navigator.mediaDevices = {};
 
-    /**
-     * Browsers that either do not implement navigator.mediaDevices
-     * at all or do not implement it completely need the getUserMedia
-     * method defined.  This shims in this function by detecting
-     * one of the supported legacy methods.
-     */
+    // Browsers that either do not implement navigator.mediaDevices
+    // at all or do not implement it completely need the getUserMedia
+    // method defined.  This shims in this function by detecting
+    // one of the supported legacy methods.
     if (!navigator.mediaDevices.getUserMedia)
         navigator.mediaDevices.getUserMedia = (navigator.getUserMedia
                 || navigator.webkitGetUserMedia


[4/6] guacamole-client git commit: GUACAMOLE-237: Update JSDoc comments for new code.

Posted by mj...@apache.org.
GUACAMOLE-237: Update JSDoc comments for new code.


Project: http://git-wip-us.apache.org/repos/asf/guacamole-client/repo
Commit: http://git-wip-us.apache.org/repos/asf/guacamole-client/commit/f0a658bb
Tree: http://git-wip-us.apache.org/repos/asf/guacamole-client/tree/f0a658bb
Diff: http://git-wip-us.apache.org/repos/asf/guacamole-client/diff/f0a658bb

Branch: refs/heads/master
Commit: f0a658bb975ea0f0abc6bbcc692212bf08434606
Parents: 4c53f28
Author: Nick Couchman <vn...@apache.org>
Authored: Wed Jan 3 12:19:48 2018 -0500
Committer: Nick Couchman <vn...@apache.org>
Committed: Wed Jan 3 12:19:48 2018 -0500

----------------------------------------------------------------------
 .../src/main/webapp/modules/AudioRecorder.js           | 13 ++++++++-----
 1 file changed, 8 insertions(+), 5 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/guacamole-client/blob/f0a658bb/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
----------------------------------------------------------------------
diff --git a/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js b/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
index 454f3f6..c1bb4eb 100644
--- a/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
+++ b/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
@@ -182,15 +182,18 @@ Guacamole.RawAudioRecorder = function RawAudioRecorder(stream, mimetype) {
     var context = Guacamole.AudioContextFactory.getAudioContext();
 
     /**
-     * A function which directly invokes the browser's implementation of
-     * navigator.mediaDevices.getUserMedia() with all provided parameters.
-     *
-     * @type Function
+     * Some browsers do not implement navigator.mediaDevices - this
+     * shims in this functionality to ensure code compatibility.
      */
-
     if (!navigator.mediaDevices)
         navigator.mediaDevices = {};
 
+    /**
+     * Browsers that either do not implement navigator.mediaDevices
+     * at all or do not implement it completely need the getUserMedia
+     * method defined.  This shims in this function by detecting
+     * one of the supported legacy methods.
+     */
     if (!navigator.mediaDevices.getUserMedia)
         navigator.mediaDevices.getUserMedia = (navigator.getUserMedia
                 || navigator.webkitGetUserMedia
diff --git a/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js b/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
index 954b79f..f925716 100644
--- a/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
+++ b/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
@@ -183,11 +183,12 @@ Guacamole.RawAudioRecorder = function RawAudioRecorder(stream, mimetype) {
 
     /**
      * A function which directly invokes the browser's implementation of
      * navigator.getUserMedia() with all provided parameters.
      *
      * @type Function
      */
-    var getUserMedia = (navigator.getUserMedia
+    var getUserMedia = (navigator.mediaDevices.getUserMedia
+            || navigator.getUserMedia
             || navigator.webkitGetUserMedia
             || navigator.mozGetUserMedia
             || navigator.msGetUserMedia).bind(navigator);


[6/6] guacamole-client git commit: GUACAMOLE-237: Merge changes migrating to navigator.mediaDevices.getUserMedia rather than deprecated navigator.getUserMedia.

Posted by mj...@apache.org.
GUACAMOLE-237: Merge changes migrating to navigator.mediaDevices.getUserMedia rather than deprecated navigator.getUserMedia.


Project: http://git-wip-us.apache.org/repos/asf/guacamole-client/repo
Commit: http://git-wip-us.apache.org/repos/asf/guacamole-client/commit/c170612c
Tree: http://git-wip-us.apache.org/repos/asf/guacamole-client/tree/c170612c
Diff: http://git-wip-us.apache.org/repos/asf/guacamole-client/diff/c170612c

Branch: refs/heads/master
Commit: c170612cd06a442887e1a20b3a1131f12d95708f
Parents: d73a0ec e1443d8
Author: Michael Jumper <mj...@apache.org>
Authored: Wed Jan 3 10:32:05 2018 -0800
Committer: Michael Jumper <mj...@apache.org>
Committed: Wed Jan 3 10:32:05 2018 -0800

----------------------------------------------------------------------
 .../src/main/webapp/modules/AudioRecorder.js    | 26 +++++++++++---------
 1 file changed, 15 insertions(+), 11 deletions(-)
----------------------------------------------------------------------



[3/6] guacamole-client git commit: GUACAMOLE-237: Simplify checks for mediaDevices and getUserMedia.

Posted by mj...@apache.org.
GUACAMOLE-237: Simplify checks for mediaDevices and getUserMedia.


Project: http://git-wip-us.apache.org/repos/asf/guacamole-client/repo
Commit: http://git-wip-us.apache.org/repos/asf/guacamole-client/commit/4c53f28a
Tree: http://git-wip-us.apache.org/repos/asf/guacamole-client/tree/4c53f28a
Diff: http://git-wip-us.apache.org/repos/asf/guacamole-client/diff/4c53f28a

Branch: refs/heads/master
Commit: 4c53f28aa235a1f9a883df3b9a101ae34821423d
Parents: f6291c0
Author: Nick Couchman <vn...@apache.org>
Authored: Tue Jan 2 12:26:22 2018 -0500
Committer: Nick Couchman <vn...@apache.org>
Committed: Tue Jan 2 12:26:22 2018 -0500

----------------------------------------------------------------------
 guacamole-common-js/src/main/webapp/modules/AudioRecorder.js | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/guacamole-client/blob/4c53f28a/guacamole-common-js/src/main/webapp/modules/AudioRecorder.js
----------------------------------------------------------------------
@@ -183,11 +183,12 @@ Guacamole.RawAudioRecorder = function RawAudioRecorder(stream, mimetype) {
     /**
      * A function which directly invokes the browser's implementation of
-     * navigator.getUserMedia() with all provided parameters.
+     * navigator.mediaDevices.getUserMedia() with all provided parameters.
      *
      * @type Function